[Cogl] [PATCH] Remove the last mentions of the cogl_rectangle*() drawing API

Damien Lespiau damien.lespiau at gmail.com
Sun Oct 21 14:07:17 PDT 2012


From: Damien Lespiau <damien.lespiau at intel.com>

---
 cogl-pango/cogl-pango-display-list.c |    4 ++--
 cogl/cogl.symbols                    |    6 ------
 2 files changed, 2 insertions(+), 8 deletions(-)

diff --git a/cogl/cogl.symbols b/cogl/cogl.symbols
index ebb1bf8..da8f658 100644
--- a/cogl/cogl.symbols
+++ b/cogl/cogl.symbols
@@ -494,12 +494,6 @@ cogl_quaternion_squad
 cogl_read_pixels
 cogl_read_pixels_flags_get_type
 
-cogl_rectangle
-cogl_rectangles
-cogl_rectangles_with_texture_coords
-cogl_rectangle_with_multitexture_coords
-cogl_rectangle_with_texture_coords
-
 cogl_renderer_add_constraint
 cogl_renderer_check_onscreen_template
 cogl_renderer_connect
diff --git a/cogl-pango/cogl-pango-display-list.c b/cogl-pango/cogl-pango-display-list.c
index d77b6fb..5a751a0 100644
--- a/cogl-pango/cogl-pango-display-list.c
+++ b/cogl-pango/cogl-pango-display-list.c
@@ -51,7 +51,7 @@ struct _CoglPangoDisplayList
   CoglPangoPipelineCache *pipeline_cache;
 };
 
 /* This matches the format expected by cogl_rectangles_with_texture_coords */
 struct _CoglPangoDisplayListRectangle
 {
   float x_1, y_1, x_2, y_2;
@@ -74,7 +74,7 @@ struct _CoglPangoDisplayListNode
       /* The texture to render these coords from */
       CoglTexture *texture;
       /* Array of rectangles in the format expected by
-         cogl_rectangles_with_texture_coords */
+         cogl_framebuffer_draw_textured_rectangles */
       GArray *rectangles;
       /* A primitive representing those vertices */
       CoglPrimitive *primitive;
@@ -51,7 +51,7 @@ struct _CoglPangoDisplayList
 };
 
-/* This matches the format expected by cogl_rectangles_with_texture_coords */
+/* Matches the format expected by cogl_framebuffer_draw_textured_rectangles */
 struct _CoglPangoDisplayListRectangle
 {
-- 
1.7.7.5



More information about the Cogl mailing list